"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTemperatureRows = exports.NOTE_FOR_AI_TEMPERATURE = void 0;
var react_1 = __importDefault(require("react"));
var lodash_1 = require("lodash");
exports.NOTE_FOR_AI_TEMPERATURE = "\n    The temperature setting controls the randomness of the generated text. \n    A value of 0 makes the AI deterministic, which means that it will always generate the same output for a given input text. \n    A value of 1 makes the engine take the most risks and use a lot of creativity.\n";
var getTemperatureRows = function (props) {
    var toShow = props.toShow, onShow = props.onShow, fieldName = props.fieldName, record = props.record, primaryColor = props.primaryColor, tab = props.tab, skipRecordUpdate = props.skipRecordUpdate, labelColor = props.labelColor, labelClassName = props.labelClassName, labelStyle = props.labelStyle;
    var defaultValue = (0, lodash_1.isNumber)(props.defaultValue) && props.defaultValue > 0
        ? props.defaultValue
        : 0;
    var fieldNameForNote = "".concat(fieldName, "Note");
    var value = tab == "run" ? props.value : record[fieldName];
    var onClickReset = function () {
        if (props.onClickReset)
            return props.onClickReset();
    };
    return [
        toShow(fieldNameForNote) && {
            fields: [
                {
                    name: fieldNameForNote,
                    type: "alert-info",
                    line: exports.NOTE_FOR_AI_TEMPERATURE,
                    onClickClose: function () {
                        onShow(fieldNameForNote, false);
                    }
                }
            ]
        },
        {
            style: { paddingBottom: 0 },
            fields: [
                {
                    name: "".concat(fieldName, "Label"),
                    lineClassName: labelClassName,
                    lineStyle: labelColor
                        ? __assign({ color: labelColor }, labelStyle) : labelStyle,
                    line: "Temperature ".concat((Math.round(((0, lodash_1.isNumber)(value) ? value : 0) * 100) / 100).toFixed(2)),
                    colStyle: {
                        maxWidth: 220,
                        minWidth: 220
                    },
                    labelSVGClassName: "self-center",
                    onClickInfo: function () {
                        onShow(fieldNameForNote, !toShow(fieldNameForNote));
                    },
                    type: "label"
                },
                {
                    colStyle: {
                        marginLeft: 0,
                        paddingLeft: 0,
                        width: 140,
                        maxWidth: 140,
                        flex: "none"
                    },
                    name: fieldName,
                    hideLabel: true,
                    stepValue: 0.02,
                    defaultValue: defaultValue,
                    maxValue: 1,
                    minValue: 0,
                    type: "slider",
                    value: value,
                    useFieldValue: tab == "run",
                    skipRecordUpdate: skipRecordUpdate,
                    onChange: props.onChange
                },
                tab == "run" &&
                    props.onClickReset && {
                    colStyle: {
                        marginLeft: 20,
                        paddingLeft: 0,
                        flex: "none"
                    },
                    name: "".concat(fieldName, "ResetButton"),
                    hideLabel: true,
                    type: "container",
                    content: (react_1.default.createElement("button", { className: "text-white p-2 bg-".concat(primaryColor.name, "-400 hover:bg-").concat(primaryColor.name, "-500 text-xs shadow hover:shadow-lg justify-center rounded mt-2 leading-none"), onClick: onClickReset }, "Reset"))
                }
            ]
        }
    ];
};
exports.getTemperatureRows = getTemperatureRows;
//# sourceMappingURL=temperature-rows.js.map